@@ -52,6 +52,7 @@ COLUMN_WIDTHS = "columnWidths"
 SHOW_TOOLBAR = "showToolbar"
 NOTIFICATION_ICON = "notificationIcon"
 WORKAROUND_APP_REGEX = "workAroundApps"
+SCRIPT_GLOBALS = "scriptGlobals"
 
 # TODO - Future functionality
 #TRACK_RECENT_ENTRY = "trackRecentEntry"
@@ -104,37 +105,6 @@ def apply_settings(settings):
     """
     for key, value in settings.iteritems():
         ConfigManager.SETTINGS[key] = value
-        
-def _chooseInterface():
-    # Choose a sensible default interface type. Get Xorg version to determine this:
-    try:
-        p = subprocess.Popen(["Xorg", "-version"], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        retCode = p.wait()
-        output = p.stdout.read().split('\n')
-        output += p.stderr.read().split('\n')
-
-        for line in output:
-            if "X Server" in line:
-                versionLine = line.strip()
-                break
-
-        version = versionLine.split(" ")[-1]
-        majorVersion, minorVersion, release = [int(i) for i in version.split(".")]
-    except:
-        minorVersion = None
-        release = None
-        
-    if minorVersion is None:
-        return iomediator.X_RECORD_INTERFACE
-    elif interface.HAS_RECORD:
-        if minorVersion < 6:
-            return iomediator.X_RECORD_INTERFACE
-        elif minorVersion == 7 and release > 5:
-            return iomediator.X_RECORD_INTERFACE
-        elif minorVersion > 7:
-            return iomediator.X_RECORD_INTERFACE
-    
-    return iomediator.X_EVDEV_INTERFACE
 
 def convert_v07_to_v08(configData):
     oldVersion = configData["version"]
@@ -199,19 +169,20 @@ class ConfigManager:
                 PROMPT_TO_SAVE: False,
                 #PREDICTIVE_LENGTH : 5,
                 ENABLE_QT4_WORKAROUND : False,
-                INTERFACE_TYPE : _chooseInterface(),
+                INTERFACE_TYPE : iomediator.X_RECORD_INTERFACE,
                 UNDO_USING_BACKSPACE : True,
                 WINDOW_DEFAULT_SIZE : (600, 400),
                 HPANE_POSITION : 150,
                 COLUMN_WIDTHS : [150, 50, 100],
                 SHOW_TOOLBAR : True,
                 NOTIFICATION_ICON : common.ICON_FILE_NOTIFICATION,
-                WORKAROUND_APP_REGEX : ".*VirtualBox.*"
+                WORKAROUND_APP_REGEX : ".*VirtualBox.*|krdc.Krdc",
                 # TODO - Future functionality
                 #TRACK_RECENT_ENTRY : True,
                 #RECENT_ENTRY_COUNT : 5,
                 #RECENT_ENTRY_MINLENGTH : 10,
                 #RECENT_ENTRY_SUGGEST : True
+                SCRIPT_GLOBALS : {}
                 }
                 
     def __init__(self, app):
@@ -233,9 +204,6 @@ class ConfigManager:
         self.toggleServiceHotkey.set_hotkey(["<super>", "<shift>"], "k")
         self.toggleServiceHotkey.enabled = True    
         
-        self.showPopupHotkey = GlobalHotkey()
-        self.showPopupHotkey.enabled = False
-        
         app.init_global_hotkeys(self)        
         
         self.load_global_config()
@@ -352,7 +320,6 @@ dialog.info_dialog("Window information",
             "userCodeDir": self.userCodeDir,
             "settings": ConfigManager.SETTINGS,
             "folders": extraFolders,
-            "showPopupHotkey": self.showPopupHotkey.get_serializable(),
             "toggleServiceHotkey": self.toggleServiceHotkey.get_serializable(),
             "configHotkey": self.configHotkey.get_serializable()
             }
@@ -394,7 +361,6 @@ dialog.info_dialog("Window information",
                 f.load()
                 self.folders.append(f)
 
-            self.showPopupHotkey.load_from_serialized(data["showPopupHotkey"])
             self.toggleServiceHotkey.load_from_serialized(data["toggleServiceHotkey"])
             self.configHotkey.load_from_serialized(data["configHotkey"])
             
@@ -521,6 +487,7 @@ dialog.info_dialog("Window information",
     
         self.userCodeDir = data["userCodeDir"]
         apply_settings(data["settings"])
+        self.workAroundApps = re.compile(self.SETTINGS[WORKAROUND_APP_REGEX])
         
         existingPaths = []
         for folder in self.folders:
@@ -533,7 +500,6 @@ dialog.info_dialog("Window information",
                 f.load()
                 self.folders.append(f)
 
-        self.showPopupHotkey.load_from_serialized(data["showPopupHotkey"])
         self.toggleServiceHotkey.load_from_serialized(data["toggleServiceHotkey"])
         self.configHotkey.load_from_serialized(data["configHotkey"])
 
@@ -544,7 +510,7 @@ dialog.info_dialog("Window information",
         _logger.info("Checking if upgrade is needed from version %s", self.VERSION)
         
         # Always reset interface type when upgrading
-        self.SETTINGS[INTERFACE_TYPE] = _chooseInterface()
+        self.SETTINGS[INTERFACE_TYPE] = iomediator.X_RECORD_INTERFACE
         _logger.info("Resetting interface type, new type: %s", self.SETTINGS[INTERFACE_TYPE])
         
         if self.VERSION < '0.70.0':
@@ -552,6 +518,11 @@ dialog.info_dialog("Window information",
             for item in self.allItems:
                 if isinstance(item, Phrase):
                     item.sendMode = SendMode.KEYBOARD
+
+        if self.VERSION < "0.82.3":
+            self.SETTINGS[WORKAROUND_APP_REGEX] += "|krdc.Krdc"
+            self.workAroundApps = re.compile(self.SETTINGS[WORKAROUND_APP_REGEX])
+            self.SETTINGS[SCRIPT_GLOBALS] = {}
         
         self.VERSION = common.VERSION    
         self.config_altered(True)
@@ -593,7 +564,6 @@ dialog.info_dialog("Window information",
         self.globalHotkeys = []
         self.globalHotkeys.append(self.configHotkey)
         self.globalHotkeys.append(self.toggleServiceHotkey)
-        self.globalHotkeys.append(self.showPopupHotkey)        
         #_logger.debug("Global hotkeys: %s", self.globalHotkeys)
         
         #_logger.debug("Hotkey folders: %s", self.hotKeyFolders)
