@@ -142,9 +142,7 @@ class Application:
         dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
         self.dbusService = common.AppService(self)
         
-        if ConfigManager.SETTINGS[IS_FIRST_RUN] or configure:
-            ConfigManager.SETTINGS[IS_FIRST_RUN] = False
-            self.show_configure()
+        if configure: self.show_configure()
             
     def init_global_hotkeys(self, configManager):
         logging.info("Initialise global hotkeys")
@@ -168,19 +166,12 @@ class Application:
         changed = self.configManager.path_created_or_modified(path)
         if changed and self.configWindow is not None: 
             self.configWindow.config_modified()
-            #if doReload:
-            #    self.configWindow.hide()
-            #    self.show_configure_async()
         
     def path_removed(self, path):
         time.sleep(0.5)
         changed = self.configManager.path_removed(path)        
         if changed and self.configWindow is not None: 
             self.configWindow.config_modified()
-            #if doReload:
-            #    self.configWindow.hide()
-            #    self.configWindow = None
-            #    self.show_configure()
         
     def unpause_service(self):
         """
