@@ -725,6 +725,7 @@ class ConfigWindow:
     def __init__(self, app):
         self.app = app
         self.cutCopiedItems = []
+        self.__warnedOfChanges = False
         
         builder = get_ui("mainwindow.xml")
         self.ui = builder.get_object("mainwindow")
@@ -848,30 +849,20 @@ class ConfigWindow:
         self.uiManager.get_action("/MenuBar/File/revert").set_sensitive(dirty)
         
     def config_modified(self):
-        Gdk.threads_enter()
-        msg = _("Changes made in other programs will not be displayed until you\
- close and reopen the AutoKey window.")
-        dlg = Gtk.MessageDialog(self.ui, type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.OK,
-                               message_format= _("Configuration has been changed on disk."))
-        dlg.format_secondary_text(msg)
+        if not self.__warnedOfChanges:
+            Gdk.threads_enter()
+            msg = _("Changes made in other programs will not be displayed until you\
+close and reopen the AutoKey window.\nThis message is only shown once per session.")
+            dlg = Gtk.MessageDialog(self.ui, type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.OK,
+                                   message_format= _("Configuration has been changed on disk."))
+            dlg.format_secondary_text(msg)
+            
+            dlg.run()
+            dlg.destroy()
+            Gdk.threads_leave()
+            self.__warnedOfChanges = True
+        
         
-        #if self.dirty:
-        #    checkButton = Gtk.CheckButton(_("Save changes before reloading (this may overwrite changes from other programs)"))    
-        #    box = dlg.get_content_area()
-        #    box.pack_end(checkButton)
-            
-        dlg.run()
-        #    if self.dirty:
-        #        if checkButton.get_active():
-        #            self.on_save()
-            
-        #    dlg.destroy()
-        #    Gdk.threads_leave()
-        #    return True
-                    
-        dlg.destroy()
-        Gdk.threads_leave()
-        #return False
         
     def update_actions(self, items, changed):
         if len(items) == 0:
@@ -879,24 +870,20 @@ class ConfigWindow:
             canCopy = False
             canRecord = False
             canMacro = False
+            canPlay = False
             enableAny = False
         else:
             canCreate = isinstance(items[0], model.Folder) and len(items) == 1
             canCopy = True
             canRecord = (not isinstance(items[0], model.Folder)) and len(items) == 1
             canMacro = isinstance(items[0], model.Phrase) and len(items) == 1
+            canPlay = isinstance(items[0], model.Script) and len(items) == 1
             enableAny = True
             for item in items:
                 if isinstance(item, model.Folder):
                     canCopy = False
                     break
         
-        #self.uiManager.get_action("/MenuBar/File/create").set_sensitive(enableAny)
-        #self.uiManager.get_action("/MenuBar/File/create/new-top-folder").set_sensitive(True)
-        #self.uiManager.get_action("/MenuBar/File/create/new-folder").set_sensitive(canCreate)
-        #self.uiManager.get_action("/MenuBar/File/create/new-phrase").set_sensitive(canCreate)
-        #self.uiManager.get_action("/MenuBar/File/create/new-script").set_sensitive(canCreate)
-        
         self.uiManager.get_action("/MenuBar/Edit/copy-item").set_sensitive(canCopy)
         self.uiManager.get_action("/MenuBar/Edit/cut-item").set_sensitive(enableAny)
         self.uiManager.get_action("/MenuBar/Edit/clone-item").set_sensitive(canCopy)
@@ -905,7 +892,7 @@ class ConfigWindow:
         self.uiManager.get_action("/MenuBar/Edit/rename").set_sensitive(enableAny)
         self.uiManager.get_action("/MenuBar/Edit/insert-macro").set_sensitive(canMacro)
         self.uiManager.get_action("/MenuBar/Tools/record").set_sensitive(canRecord)
-        self.uiManager.get_action("/MenuBar/Tools/run").set_sensitive(canRecord)
+        self.uiManager.get_action("/MenuBar/Tools/run").set_sensitive(canPlay)
         
         
         if changed:
@@ -1153,7 +1140,7 @@ class ConfigWindow:
         theModel, selectedPaths = selection.get_selected_rows()
         refs = []
         for path in selectedPaths:
-            refs.append(Gtk.TreeRowReference(theModel, path))
+            refs.append(Gtk.TreeRowReference.new(theModel, path))
 
         modified = False
         
@@ -1329,7 +1316,10 @@ class ConfigWindow:
         dlg.destroy()
     
     def on_treeWidget_row_activated(self, widget, path, viewColumn, data=None):
-        widget.expand_row(path, False)
+        if widget.row_expanded(path):
+            widget.collapse_row(path)
+        else:
+            widget.expand_row(path, False)
         
     def on_treeWidget_row_collapsed(self, widget, tIter, path, data=None):
         widget.columns_autosize()
