@@ -219,7 +219,7 @@ class XInterfaceBase(threading.Thread):
             lines = output.splitlines()
             
             for line in lines:
-                if "gnome-shell" in line or "cinnamon" in line:
+                if "gnome-shell" in line or "cinnamon" in line or "unity" in line:
                     return True
         except:
             pass # since this is just a nasty workaround, if anything goes wrong just disable it 
@@ -1095,6 +1095,8 @@ XK_TO_AK_MAP = {
            XK.XK_Super_R : Key.SUPER,
            XK.XK_Hyper_L : Key.HYPER,
            XK.XK_Hyper_R : Key.HYPER,
+           XK.XK_Meta_L : Key.META,
+           XK.XK_Meta_R : Key.META,
            XK.XK_Num_Lock : Key.NUMLOCK,
            #SPACE : Key.SPACE,
            XK.XK_Tab : Key.TAB,
